FinishResult

Enum FinishResult 

pub enum FinishResult {
    Done(Finished),
    Retry {
        retry_id: i64,
        dh_params: DhParamsForRetry,
        nonce: [u8; 16],
        server_nonce: [u8; 16],
        new_nonce: [u8; 32],
    },
}
Result of finish either the handshake is done, or the server wants us to retry step 3 with the auth_key_aux_hash as retry_id.

Variants



Done(Finished)

Handshake complete.



Retry

Server sent dh_gen_retry. Call retry_step3 with the returned retry_id and the stored DhParamsForRetry from the previous Step3.

Fields

retry_id: i64

The auth_key_aux_hash to embed as retry_id in the next attempt.

dh_params: DhParamsForRetry

DH parameters to feed back into retry_step3.

nonce: [u8; 16]

Client nonce from the original step 1.

server_nonce: [u8; 16]

Server nonce from the ResPQ response.

new_nonce: [u8; 32]

Fresh nonce generated in step 2.