Module encrypted

Module encrypted 

Encrypted MTProto message construction and parsing.

Structs

DecryptedMessage
The inner payload extracted from a successfully decrypted server frame.
EncryptedSession
MTProto 2.0 encrypted session state.

Enums

DecryptError
Errors that can occur when decrypting a server message.

Functions

new_seen_msg_ids
Allocate a fresh seen-msg_id ring.

Type Aliases

SeenMsgIds
Shared, persistent dedup ring for server msg_ids.